| Title: | Performance Criteria Modeler for Discrete Trial Training |
|---|---|
| Description: | Provides a tool for computing probabilities and other quantities that are relevant in selecting performance criteria for discrete trial training. The main function, miebl(), computes Bayesian and frequentist probabilities and bounds for each of n possible performance criterion choices when attempting to determine a student's true mastery level by counting their number of successful attempts at displaying learning among n trials. The reporting function miebl_re() takes output from miebl() and prepares it into a brief report for a specific criterion. miebl_cp() combines 2 to 5 distributions of true mastery level given performance criterion in one plot for comparison. Ramos (2025) <doi:10.1007/s40617-025-01058-9>. |
| Authors: | Mark Ramos [aut, cre, cph] |
| Maintainer: | Mark Ramos <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.0 |
| Built: | 2026-05-20 08:20:32 UTC |
| Source: | https://github.com/cran/miebl |
Compute relevant probabilities and estimates for selecting performance criteria
miebl(n, tr = 0.9, shape1 = 0.5, shape2 = shape1, a = 0.05)miebl(n, tr = 0.9, shape1 = 0.5, shape2 = shape1, a = 0.05)
n |
number of trials |
tr |
true desired mastery level (default is 90%) |
shape1 |
shape1 parameter for beta prior (default is 0.5) |
shape2 |
shape2 parameter for beta prior (default is shape1 which means default is Jeffreys prior) |
a |
significance level (defaul is 0.05) |
A list of tables
miebl(n=5,tr=0.8,shape1=1,a=0.10) # Creates results for 5 trials for 80% true mastery level w/ uniform prior and 0.10 significance.miebl(n=5,tr=0.8,shape1=1,a=0.10) # Creates results for 5 trials for 80% true mastery level w/ uniform prior and 0.10 significance.
Compares posterior distributions from different reports
miebl_cp(R1, R2, R3 = NULL, R4 = NULL, R5 = NULL)miebl_cp(R1, R2, R3 = NULL, R4 = NULL, R5 = NULL)
R1 |
object produced by miebl_re; start from highest performance criterion to lowest |
R2 |
object produced by miebl_re |
R3 |
object produced by miebl_re |
R4 |
object produced by miebl_re |
R5 |
object produced by miebl_re |
a combined plot of the posterior distributions for each performance criterion
#create a miebl output for default 90% desired true mastery xx<-miebl(10) #Uses the miebl output for miebl_re for 90% and 80% performance criterion r1<-miebl_re(xx,mc=90) r2<-miebl_re(xx,mc=80) miebl_cp(r1,r2)#create a miebl output for default 90% desired true mastery xx<-miebl(10) #Uses the miebl output for miebl_re for 90% and 80% performance criterion r1<-miebl_re(xx,mc=90) r2<-miebl_re(xx,mc=80) miebl_cp(r1,r2)
Creates a report for a specific performance criterion from a miebl output
miebl_re(mb, X = nrow(mb) - 1, mc = 100)miebl_re(mb, X = nrow(mb) - 1, mc = 100)
mb |
object produced by miebl |
X |
Number of correct responses for the performance criterion |
mc |
performance criterion expressed as percent e.g. 90% performance criterion is 90 |
a report on the performance criterion selected with respect to the true mastery level desired
#create a miebl output for default 90% desired true mastery xx<-miebl(10) #Uses the miebl output for miebl_re for 90% performance criterion miebl_re(xx,mc=90)#create a miebl output for default 90% desired true mastery xx<-miebl(10) #Uses the miebl output for miebl_re for 90% performance criterion miebl_re(xx,mc=90)